.. Varlord documentation master file

Varlord Documentation
======================

Welcome to Varlord's documentation!

Varlord is a powerful Python configuration management library that provides a unified interface 
for loading configuration from multiple sources with customizable priority ordering and optional 
dynamic updates via etcd.

.. grid:: 2
   :gutter: 2
   :margin: 2

   .. grid-item-card::
      :link: introduction
      :link-type: doc
      
      **Introduction**
      
      Overview and key concepts of Varlord.

   .. grid-item-card::
      :link: quickstart
      :link-type: doc
      
      **Quick Start**
      
      Get started with Varlord in minutes.

   .. grid-item-card::
      :link: tutorial/index
      :link-type: doc
      
      **Tutorial**
      
      Step-by-step guide from basics to advanced features.

   .. grid-item-card::
      :link: design
      :link-type: doc
      
      **System Design**
      
      Detailed architecture and design principles.

   .. grid-item-card::
      :link: user_guide/index
      :link-type: doc
      
      **User Guide**
      
      Comprehensive guide to using Varlord.

   .. grid-item-card::
      :link: api_reference/index
      :link-type: doc
      
      **API Reference**
      
      Complete API documentation.

   .. grid-item-card::
      :link: examples/index
      :link-type: doc
      
      **Examples**
      
      Real-world usage examples.

.. toctree::
   :maxdepth: 2
   :caption: Documentation
   :hidden:

   introduction
   quickstart
   tutorial/index
   design
   user_guide/index
   api_reference/index
   examples/index
   changelog

